@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudfront._jsii
 import aws_cdk.aws_iam._jsii
@@ -20,9 +20,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-static-website",
-    "1.1.10",
+    "1.1.12",
     __name__[0:-6],
-    "cdk-static-website@1.1.10.jsii.tgz",
+    "cdk-static-website@1.1.12.jsii.tgz",
 )
 
 __all__ = [
